@@ -26,7 +26,7 @@
  * SOFTWARE.
  */
 
-#include "cogl-config.h"
+#include "config.h"
 
 #include <glib.h>
 
@@ -76,7 +76,7 @@ static void
 cogl_pango_glyph_cache_value_free (CoglPangoGlyphCacheValue *value)
 {
   if (value->texture)
-    cogl_object_unref (value->texture);
+    g_object_unref (value->texture);
   g_free (value);
 }
 
@@ -156,7 +156,7 @@ cogl_pango_glyph_cache_reorganize_cb (void *user_data)
 void
 cogl_pango_glyph_cache_clear (CoglPangoGlyphCache *cache)
 {
-  g_slist_foreach (cache->atlases, (GFunc) cogl_object_unref, NULL);
+  g_slist_foreach (cache->atlases, (GFunc) g_object_unref, NULL);
   g_slist_free (cache->atlases);
   cache->atlases = NULL;
   cache->has_dirty_glyphs = FALSE;
@@ -169,7 +169,7 @@ cogl_pango_glyph_cache_free (CoglPangoGlyphCache *cache)
 {
   if (cache->using_global_atlas)
     {
-      _cogl_atlas_texture_remove_reorganize_callback (
+      cogl_atlas_texture_remove_reorganize_callback (
                                   cache->ctx,
                                   cogl_pango_glyph_cache_reorganize_cb, cache);
     }
@@ -184,16 +184,16 @@ cogl_pango_glyph_cache_free (CoglPangoGlyphCache *cache)
 }
 
 static void
-cogl_pango_glyph_cache_update_position_cb (void *user_data,
-                                           CoglTexture *new_texture,
-                                           const CoglRectangleMapEntry *rect)
+cogl_pango_glyph_cache_update_position_cb (void               *user_data,
+                                           CoglTexture        *new_texture,
+                                           const MtkRectangle *rect)
 {
   CoglPangoGlyphCacheValue *value = user_data;
   float tex_width, tex_height;
 
   if (value->texture)
-    cogl_object_unref (value->texture);
-  value->texture = cogl_object_ref (new_texture);
+    g_object_unref (value->texture);
+  value->texture = g_object_ref (new_texture);
 
   tex_width = cogl_texture_get_width (new_texture);
   tex_height = cogl_texture_get_height (new_texture);
@@ -216,7 +216,7 @@ cogl_pango_glyph_cache_add_to_global_atlas (CoglPangoGlyphCache *cache,
                                             PangoGlyph glyph,
                                             CoglPangoGlyphCacheValue *value)
 {
-  CoglAtlasTexture *texture;
+  CoglTexture *texture;
   GError *ignore_error = NULL;
 
   if (COGL_DEBUG_ENABLED (COGL_DEBUG_DISABLE_SHARED_ATLAS))
@@ -230,13 +230,13 @@ cogl_pango_glyph_cache_add_to_global_atlas (CoglPangoGlyphCache *cache,
   texture = cogl_atlas_texture_new_with_size (cache->ctx,
                                               value->draw_width,
                                               value->draw_height);
-  if (!cogl_texture_allocate (COGL_TEXTURE (texture), &ignore_error))
+  if (!cogl_texture_allocate (texture, &ignore_error))
     {
       g_error_free (ignore_error);
       return FALSE;
     }
 
-  value->texture = COGL_TEXTURE (texture);
+  value->texture = texture;
   value->tx1 = 0;
   value->ty1 = 0;
   value->tx2 = 1;
@@ -250,7 +250,7 @@ cogl_pango_glyph_cache_add_to_global_atlas (CoglPangoGlyphCache *cache,
      reorganization */
   if (!cache->using_global_atlas)
     {
-      _cogl_atlas_texture_add_reorganize_callback
+      cogl_atlas_texture_add_reorganize_callback
         (cache->ctx,
          cogl_pango_glyph_cache_reorganize_cb, cache);
       cache->using_global_atlas = TRUE;
@@ -261,6 +261,7 @@ cogl_pango_glyph_cache_add_to_global_atlas (CoglPangoGlyphCache *cache,
 
 static gboolean
 cogl_pango_glyph_cache_add_to_local_atlas (CoglPangoGlyphCache *cache,
+                                           CoglContext         *context,
                                            PangoFont *font,
                                            PangoGlyph glyph,
                                            CoglPangoGlyphCacheValue *value)
@@ -270,10 +271,10 @@ cogl_pango_glyph_cache_add_to_local_atlas (CoglPangoGlyphCache *cache,
 
   /* Look for an atlas that can reserve the space */
   for (l = cache->atlases; l; l = l->next)
-    if (_cogl_atlas_reserve_space (l->data,
-                                   value->draw_width + 1,
-                                   value->draw_height + 1,
-                                   value))
+    if (cogl_atlas_reserve_space (l->data,
+                                  value->draw_width + 1,
+                                  value->draw_height + 1,
+                                  value))
       {
         atlas = l->data;
         break;
@@ -282,23 +283,24 @@ cogl_pango_glyph_cache_add_to_local_atlas (CoglPangoGlyphCache *cache,
   /* If we couldn't find one then start a new atlas */
   if (atlas == NULL)
     {
-      atlas = _cogl_atlas_new (COGL_PIXEL_FORMAT_A_8,
-                               COGL_ATLAS_CLEAR_TEXTURE |
-                               COGL_ATLAS_DISABLE_MIGRATION,
-                               cogl_pango_glyph_cache_update_position_cb);
+      atlas = cogl_atlas_new (context,
+                              COGL_PIXEL_FORMAT_A_8,
+                              COGL_ATLAS_CLEAR_TEXTURE |
+                              COGL_ATLAS_DISABLE_MIGRATION,
+                              cogl_pango_glyph_cache_update_position_cb);
       COGL_NOTE (ATLAS, "Created new atlas for glyphs: %p", atlas);
       /* If we still can't reserve space then something has gone
          seriously wrong so we'll just give up */
-      if (!_cogl_atlas_reserve_space (atlas,
-                                      value->draw_width + 1,
-                                      value->draw_height + 1,
-                                      value))
+      if (!cogl_atlas_reserve_space (atlas,
+                                     value->draw_width + 1,
+                                     value->draw_height + 1,
+                                     value))
         {
-          cogl_object_unref (atlas);
+          g_object_unref (atlas);
           return FALSE;
         }
 
-      _cogl_atlas_add_reorganize_callback
+      cogl_atlas_add_reorganize_callback
         (atlas, cogl_pango_glyph_cache_reorganize_cb, NULL, cache);
 
       cache->atlases = g_slist_prepend (cache->atlases, atlas);
@@ -309,6 +311,7 @@ cogl_pango_glyph_cache_add_to_local_atlas (CoglPangoGlyphCache *cache,
 
 CoglPangoGlyphCacheValue *
 cogl_pango_glyph_cache_lookup (CoglPangoGlyphCache *cache,
+                               CoglContext         *context,
                                gboolean             create,
                                PangoFont           *font,
                                PangoGlyph           glyph)
@@ -350,6 +353,7 @@ cogl_pango_glyph_cache_lookup (CoglPangoGlyphCache *cache,
                                                            value) &&
               /* If it fails try the local atlas */
               !cogl_pango_glyph_cache_add_to_local_atlas (cache,
+                                                          context,
                                                           font,
                                                           glyph,
                                                           value))
