@@ -32,8 +32,7 @@
  *   Matthew Allum  <mallum@openedhand.com>
  */
 
-#ifndef __COGL_PANGO_H__
-#define __COGL_PANGO_H__
+#pragma once
 
 #include <glib-object.h>
 #include <pango/pango.h>
@@ -48,7 +47,7 @@
  * or specific internal cogl headers here...
  */
 #ifndef COGL_COMPILATION
-#include <cogl/cogl.h>
+#include "cogl/cogl.h"
 #else
 #include "cogl/cogl-context.h"
 #include "cogl/cogl-macros.h"
@@ -66,6 +65,9 @@ G_BEGIN_DECLS
 
 typedef PangoCairoFontMap CoglPangoFontMap;
 
+typedef void (* CoglPangoPipelineSetup) (CoglPipeline *pipeline,
+                                         gpointer      user_data);
+
 /**
  * cogl_pango_font_map_new:
  *
@@ -74,7 +76,7 @@ typedef PangoCairoFontMap CoglPangoFontMap;
  * Return value: (transfer full): the newly created #PangoFontMap
  */
 COGL_EXPORT PangoFontMap *
-cogl_pango_font_map_new (void);
+cogl_pango_font_map_new (CoglContext *context);
 
 /**
  * cogl_pango_font_map_create_context:
@@ -93,9 +95,9 @@ cogl_pango_font_map_create_context (CoglPangoFontMap *font_map);
  * @dpi: The resolution in "dots per inch". (Physical inches aren't
  *       actually involved; the terminology is conventional.)
  *
- * Sets the resolution for the @font_map. 
- * 
- * This is a scale factor between points specified in a 
+ * Sets the resolution for the @font_map.
+ *
+ * This is a scale factor between points specified in a
  * [struct@Pango.FontDescription] and Cogl units.
  * The default value is %96, meaning that a 10 point font will be 13
  * units high. (10 * 96. / 72. = 13.3).
@@ -104,15 +106,6 @@ COGL_EXPORT void
 cogl_pango_font_map_set_resolution (CoglPangoFontMap *font_map,
                                     double dpi);
 
-/**
- * cogl_pango_font_map_clear_glyph_cache:
- * @font_map: a #CoglPangoFontMap
- *
- * Clears the glyph cache for @font_map.
- */
-COGL_EXPORT void
-cogl_pango_font_map_clear_glyph_cache (CoglPangoFontMap *font_map);
-
 /**
  * cogl_pango_ensure_glyph_cache_for_layout:
  * @layout: A #PangoLayout
@@ -126,30 +119,6 @@ cogl_pango_font_map_clear_glyph_cache (CoglPangoFontMap *font_map);
 COGL_EXPORT void
 cogl_pango_ensure_glyph_cache_for_layout (PangoLayout *layout);
 
-/**
- * cogl_pango_font_map_set_use_mipmapping:
- * @font_map: a #CoglPangoFontMap
- * @value: %TRUE to enable the use of mipmapping
- *
- * Sets whether the renderer for the passed font map should use
- * mipmapping when rendering a [class@Pango.Layout].
- */
-COGL_EXPORT void
-cogl_pango_font_map_set_use_mipmapping (CoglPangoFontMap *font_map,
-                                        gboolean value);
-
-/**
- * cogl_pango_font_map_get_use_mipmapping:
- * @font_map: a #CoglPangoFontMap
- *
- * Retrieves whether the [class@CoglPango.Renderer] used by @font_map will use
- * mipmapping when rendering the glyphs.
- *
- * Return value: %TRUE if mipmapping is used, %FALSE otherwise.
- */
-COGL_EXPORT gboolean
-cogl_pango_font_map_get_use_mipmapping (CoglPangoFontMap *font_map);
-
 /**
  * cogl_pango_font_map_get_renderer:
  * @font_map: a #CoglPangoFontMap
@@ -173,11 +142,13 @@ cogl_pango_font_map_get_renderer (CoglPangoFontMap *font_map);
  * @y) within the `framebuffer`'s current model-view coordinate space.
  */
 COGL_EXPORT void
-cogl_pango_show_layout (CoglFramebuffer *framebuffer,
-                        PangoLayout *layout,
-                        float x,
-                        float y,
-                        const CoglColor *color);
+cogl_pango_show_layout (CoglFramebuffer        *framebuffer,
+                        PangoLayout            *layout,
+                        float                   x,
+                        float                   y,
+                        const CoglColor        *color,
+                        CoglPangoPipelineSetup  pipeline_setup,
+                        gpointer                pipeline_setup_userdata);
 
 /**
  * cogl_pango_show_layout_line: (skip)
@@ -191,11 +162,13 @@ cogl_pango_show_layout (CoglFramebuffer *framebuffer,
  * @y) within the `framebuffer`'s current model-view coordinate space.
  */
 COGL_EXPORT void
-cogl_pango_show_layout_line (CoglFramebuffer *framebuffer,
-                             PangoLayoutLine *line,
-                             float x,
-                             float y,
-                             const CoglColor *color);
+cogl_pango_show_layout_line (CoglFramebuffer        *framebuffer,
+                             PangoLayoutLine        *line,
+                             float                   x,
+                             float                   y,
+                             const CoglColor        *color,
+                             CoglPangoPipelineSetup  pipeline_setup,
+                             gpointer                pipeline_setup_userdata);
 
 
 #define COGL_PANGO_TYPE_RENDERER                (cogl_pango_renderer_get_type ())
@@ -212,5 +185,3 @@ typedef struct _CoglPangoRendererClass CoglPangoRendererClass;
 COGL_EXPORT GType cogl_pango_renderer_get_type (void) G_GNUC_CONST;
 
 G_END_DECLS
-
-#endif /* __COGL_PANGO_H__ */
