@@ -32,38 +32,16 @@
  *   Robert Bragg <robert@linux.intel.com>
  */
 
-#ifndef __COGL_BUFFER_PRIVATE_H__
-#define __COGL_BUFFER_PRIVATE_H__
+#pragma once
 
 #include <glib.h>
 
-#include "cogl-object-private.h"
-#include "cogl-buffer.h"
-#include "cogl-context.h"
-#include "cogl-gl-header.h"
+#include "cogl/cogl-buffer.h"
+#include "cogl/cogl-context.h"
+#include "cogl/cogl-gl-header.h"
 
 G_BEGIN_DECLS
 
-typedef struct _CoglBufferVtable CoglBufferVtable;
-
-struct _CoglBufferVtable
-{
-  void * (* map_range) (CoglBuffer *buffer,
-                        size_t offset,
-                        size_t size,
-                        CoglBufferAccess access,
-                        CoglBufferMapHint hints,
-                        GError **error);
-
-  void (* unmap) (CoglBuffer *buffer);
-
-  gboolean (* set_data) (CoglBuffer *buffer,
-                         unsigned int offset,
-                         const void *data,
-                         unsigned int size,
-                         GError **error);
-};
-
 typedef enum _CoglBufferFlags
 {
   COGL_BUFFER_FLAG_NONE            = 0,
@@ -72,85 +50,45 @@ typedef enum _CoglBufferFlags
   COGL_BUFFER_FLAG_MAPPED_FALLBACK = 1UL << 2
 } CoglBufferFlags;
 
-typedef enum
-{
-  COGL_BUFFER_USAGE_HINT_TEXTURE,
-  COGL_BUFFER_USAGE_HINT_ATTRIBUTE_BUFFER,
-  COGL_BUFFER_USAGE_HINT_INDEX_BUFFER
-} CoglBufferUsageHint;
-
-typedef enum
-{
-  COGL_BUFFER_BIND_TARGET_PIXEL_PACK,
-  COGL_BUFFER_BIND_TARGET_PIXEL_UNPACK,
-  COGL_BUFFER_BIND_TARGET_ATTRIBUTE_BUFFER,
-  COGL_BUFFER_BIND_TARGET_INDEX_BUFFER,
-
-  COGL_BUFFER_BIND_TARGET_COUNT
-} CoglBufferBindTarget;
-
 struct _CoglBuffer
 {
-  CoglObject _parent;
+  GObject parent_instance;
 
   CoglContext *context;
 
-  CoglBufferVtable vtable;
-
   CoglBufferBindTarget last_target;
 
   CoglBufferFlags flags;
 
   GLuint gl_handle; /* OpenGL handle */
   unsigned int size; /* size of the buffer, in bytes */
-  CoglBufferUsageHint usage_hint;
   CoglBufferUpdateHint update_hint;
 
   /* points to the mapped memory when the CoglBuffer is a VBO, PBO,
    * ... or points to allocated memory in the fallback paths */
   uint8_t *data;
 
-  int immutable_ref;
+  unsigned int store_created : 1;
 
-  unsigned int store_created:1;
+  void * (* map_range) (CoglBuffer       *buffer,
+                        size_t            offset,
+                        size_t            size,
+                        CoglBufferAccess  access,
+                        CoglBufferMapHint hints,
+                        GError          **error);
+
+  void (* unmap) (CoglBuffer *buffer);
+
+  gboolean (* set_data) (CoglBuffer  *buffer,
+                         unsigned int offset,
+                         const void  *data,
+                         unsigned int size,
+                         GError     **error);
+};
+struct _CoglBufferClass
+{
+  GObjectClass parent_class;
 };
-
-/* This is used to register a type to the list of handle types that
-   will be considered a texture in cogl_is_texture() */
-void
-_cogl_buffer_register_buffer_type (const CoglObjectClass *klass);
-
-#define COGL_BUFFER_DEFINE(TypeName, type_name)                         \
-  COGL_OBJECT_DEFINE_WITH_CODE                                          \
-  (TypeName, type_name,                                                 \
-   _cogl_buffer_register_buffer_type (&_cogl_##type_name##_class))
-
-void
-_cogl_buffer_initialize (CoglBuffer *buffer,
-                         CoglContext *context,
-                         size_t size,
-                         CoglBufferBindTarget default_target,
-                         CoglBufferUsageHint usage_hint,
-                         CoglBufferUpdateHint update_hint);
-
-void
-_cogl_buffer_fini (CoglBuffer *buffer);
-
-CoglBufferUsageHint
-_cogl_buffer_get_usage_hint (CoglBuffer *buffer);
-
-CoglBuffer *
-_cogl_buffer_immutable_ref (CoglBuffer *buffer);
-
-void
-_cogl_buffer_immutable_unref (CoglBuffer *buffer);
-
-gboolean
-_cogl_buffer_set_data (CoglBuffer *buffer,
-                       size_t offset,
-                       const void *data,
-                       size_t size,
-                       GError **error);
 
 void *
 _cogl_buffer_map (CoglBuffer *buffer,
@@ -168,12 +106,8 @@ void *
 _cogl_buffer_map_range_for_fill_or_fallback (CoglBuffer *buffer,
                                              size_t offset,
                                              size_t size);
-COGL_EXPORT void *
-_cogl_buffer_map_for_fill_or_fallback (CoglBuffer *buffer);
 
-COGL_EXPORT void
+void
 _cogl_buffer_unmap_for_fill_or_fallback (CoglBuffer *buffer);
 
 G_END_DECLS
-
-#endif /* __COGL_BUFFER_PRIVATE_H__ */
