@@ -73,10 +73,3 @@ _cogl_magazine_new (size_t chunk_size, int initial_chunk_count)
 
   return magazine;
 }
-
-void
-_cogl_magazine_free (CoglMagazine *magazine)
-{
-  _cogl_memory_stack_free (magazine->stack);
-  g_free (magazine);
-}
