@@ -32,7 +32,6 @@
 
 #include <gmodule.h>
 
-#include "cogl/cogl-object-private.h"
 #include "cogl/cogl-driver.h"
 #include "cogl/cogl-texture-driver.h"
 #include "cogl/cogl-context.h"
@@ -43,7 +42,10 @@ typedef const CoglWinsysVtable *(*CoglCustomWinsysVtableGetter) (CoglRenderer *r
 
 struct _CoglRenderer
 {
-  CoglObject _parent;
+  GObject parent_instance;
+
+  CoglDisplay *display;
+
   gboolean connected;
   CoglDriver driver_override;
   const CoglDriverVtable *driver_vtable;
@@ -51,21 +53,11 @@ struct _CoglRenderer
   const CoglWinsysVtable *winsys_vtable;
   void *custom_winsys_user_data;
   CoglCustomWinsysVtableGetter custom_winsys_vtable_getter;
-  CoglWinsysID winsys_id_override;
-  GList *constraints;
-
-  GArray *poll_fds;
-  int poll_fds_age;
-  GList *poll_sources;
 
   CoglList idle_closures;
 
-  GList *outputs;
-
-#ifdef COGL_HAS_XLIB
+#ifdef HAVE_X11
   Display *foreign_xdpy;
-  gboolean xlib_enable_event_retrieval;
-  gboolean xlib_want_reset_on_video_memory_purge;
 #endif
 
   CoglDriver driver;
@@ -81,10 +73,6 @@ struct _CoglRenderer
 typedef CoglFilterReturn (* CoglNativeFilterFunc) (void *native_event,
                                                    void *data);
 
-CoglFilterReturn
-_cogl_renderer_handle_native_event (CoglRenderer *renderer,
-                                    void *event);
-
 void
 _cogl_renderer_add_native_filter (CoglRenderer *renderer,
                                   CoglNativeFilterFunc func,
@@ -94,8 +82,3 @@ void
 _cogl_renderer_remove_native_filter (CoglRenderer *renderer,
                                      CoglNativeFilterFunc func,
                                      void *data);
-
-void *
-_cogl_renderer_get_proc_address (CoglRenderer *renderer,
-                                 const char *name,
-                                 gboolean in_core);
