@@ -110,14 +110,14 @@ typedef enum _EvdevButtonType
 } EvdevButtonType;
 
 static int
-update_button_count_in_impl (MetaVirtualInputDeviceNative *virtual_evdev,
+update_button_count_in_impl (MetaVirtualInputDeviceNative *virtual_native,
                              uint32_t                      button,
                              uint32_t                      state)
 {
   if (state)
-    return ++virtual_evdev->impl_state->button_count[button];
+    return ++virtual_native->impl_state->button_count[button];
   else
-    return --virtual_evdev->impl_state->button_count[button];
+    return --virtual_native->impl_state->button_count[button];
 }
 
 static EvdevButtonType
@@ -207,16 +207,16 @@ release_device_in_impl (GTask *task)
 static gboolean
 notify_relative_motion_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventMotion *event = g_task_get_task_data (task);
 
   if (event->time_us == CLUTTER_CURRENT_TIME)
     event->time_us = g_get_monotonic_time ();
 
   meta_seat_impl_notify_relative_motion_in_impl (seat,
-                                                 virtual_evdev->impl_state->device,
+                                                 virtual_native->impl_state->device,
                                                  event->time_us,
                                                  (float) event->x,
                                                  (float) event->y,
@@ -234,11 +234,11 @@ meta_virtual_input_device_native_notify_relative_motion (ClutterVirtualInputDevi
                                                          double                     dy)
 {
   MetaVirtualEventMotion *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventMotion, 1);
   event->time_us = time_us;
@@ -247,7 +247,7 @@ meta_virtual_input_device_native_notify_relative_motion (ClutterVirtualInputDevi
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_relative_motion_in_impl);
   g_object_unref (task);
 }
@@ -255,16 +255,16 @@ meta_virtual_input_device_native_notify_relative_motion (ClutterVirtualInputDevi
 static gboolean
 notify_absolute_motion_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventMotion *event = g_task_get_task_data (task);
 
   if (event->time_us == CLUTTER_CURRENT_TIME)
     event->time_us = g_get_monotonic_time ();
 
   meta_seat_impl_notify_absolute_motion_in_impl (seat,
-                                                 virtual_evdev->impl_state->device,
+                                                 virtual_native->impl_state->device,
                                                  event->time_us,
                                                  (float) event->x,
                                                  (float) event->y,
@@ -280,11 +280,11 @@ meta_virtual_input_device_native_notify_absolute_motion (ClutterVirtualInputDevi
                                                          double                     y)
 {
   MetaVirtualEventMotion *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventMotion, 1);
   event->time_us = time_us;
@@ -293,7 +293,7 @@ meta_virtual_input_device_native_notify_absolute_motion (ClutterVirtualInputDevi
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_absolute_motion_in_impl);
   g_object_unref (task);
 }
@@ -301,9 +301,9 @@ meta_virtual_input_device_native_notify_absolute_motion (ClutterVirtualInputDevi
 static gboolean
 notify_button_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventButton *event = g_task_get_task_data (task);
   int button_count;
   int evdev_button;
@@ -320,14 +320,14 @@ notify_button_in_impl (GTask *task)
       goto out;
     }
 
-  button_count = update_button_count_in_impl (virtual_evdev, evdev_button,
+  button_count = update_button_count_in_impl (virtual_native, evdev_button,
                                               event->button_state);
   if (button_count < 0 || button_count > 1)
     {
       g_warning ("Received multiple virtual 0x%x button %s (ignoring)", evdev_button,
                  event->button_state == CLUTTER_BUTTON_STATE_PRESSED ?
                  "presses" : "releases");
-      update_button_count_in_impl (virtual_evdev, evdev_button, 1 - event->button_state);
+      update_button_count_in_impl (virtual_native, evdev_button, 1 - event->button_state);
       goto out;
     }
 
@@ -335,10 +335,10 @@ notify_button_in_impl (GTask *task)
               "Emitting virtual button-%s of button 0x%x (device %p)",
               event->button_state == CLUTTER_BUTTON_STATE_PRESSED ?
               "press" : "release",
-              evdev_button, virtual_evdev);
+              evdev_button, virtual_native);
 
   meta_seat_impl_notify_button_in_impl (seat,
-					virtual_evdev->impl_state->device,
+					virtual_native->impl_state->device,
 					event->time_us,
 					evdev_button,
 					event->button_state);
@@ -354,11 +354,11 @@ meta_virtual_input_device_native_notify_button (ClutterVirtualInputDevice *virtu
                                                 ClutterButtonState         button_state)
 {
   MetaVirtualEventButton *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventButton, 1);
   event->time_us = time_us;
@@ -367,7 +367,7 @@ meta_virtual_input_device_native_notify_button (ClutterVirtualInputDevice *virtu
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_button_in_impl);
   g_object_unref (task);
 }
@@ -375,9 +375,9 @@ meta_virtual_input_device_native_notify_button (ClutterVirtualInputDevice *virtu
 static gboolean
 notify_key_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventKey *event = g_task_get_task_data (task);
   int key_count;
 
@@ -390,23 +390,23 @@ notify_key_in_impl (GTask *task)
       goto out;
     }
 
-  key_count = update_button_count_in_impl (virtual_evdev, event->key, event->key_state);
+  key_count = update_button_count_in_impl (virtual_native, event->key, event->key_state);
   if (key_count < 0 || key_count > 1)
     {
       g_warning ("Received multiple virtual 0x%x key %s (ignoring)", event->key,
                  event->key_state == CLUTTER_KEY_STATE_PRESSED ?
                  "presses" : "releases");
-      update_button_count_in_impl (virtual_evdev, event->key, 1 - event->key_state);
+      update_button_count_in_impl (virtual_native, event->key, 1 - event->key_state);
       goto out;
     }
 
   meta_topic (META_DEBUG_INPUT,
               "Emitting virtual key-%s of key 0x%x (device %p)",
               event->key_state == CLUTTER_KEY_STATE_PRESSED ? "press" : "release",
-              event->key, virtual_evdev);
+              event->key, virtual_native);
 
   meta_seat_impl_notify_key_in_impl (seat,
-				     virtual_evdev->impl_state->device,
+				     virtual_native->impl_state->device,
 				     event->time_us,
 				     event->key,
 				     event->key_state,
@@ -424,11 +424,11 @@ meta_virtual_input_device_native_notify_key (ClutterVirtualInputDevice *virtual_
                                              ClutterKeyState            key_state)
 {
   MetaVirtualEventKey *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventKey, 1);
   event->time_us = time_us;
@@ -437,7 +437,7 @@ meta_virtual_input_device_native_notify_key (ClutterVirtualInputDevice *virtual_
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_key_in_impl);
   g_object_unref (task);
 }
@@ -448,7 +448,7 @@ pick_keycode_for_keyval_in_current_group_in_impl (ClutterVirtualInputDevice *vir
 						  guint                     *keycode_out,
 						  guint                     *level_out)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   ClutterBackend *backend;
   ClutterKeymap *keymap;
@@ -460,7 +460,7 @@ pick_keycode_for_keyval_in_current_group_in_impl (ClutterVirtualInputDevice *vir
   backend = clutter_get_default_backend ();
   keymap = clutter_seat_get_keymap (clutter_backend_get_default_seat (backend));
   xkb_keymap = meta_keymap_native_get_keyboard_map_in_impl (META_KEYMAP_NATIVE (keymap));
-  state = meta_seat_impl_get_xkb_state_in_impl (virtual_evdev->seat->impl);
+  state = meta_seat_impl_get_xkb_state_in_impl (virtual_native->seat->impl);
 
   layout = xkb_state_serialize_layout (state, XKB_STATE_LAYOUT_EFFECTIVE);
   min_keycode = xkb_keymap_min_keycode (xkb_keymap);
@@ -496,7 +496,7 @@ apply_level_modifiers_in_impl (ClutterVirtualInputDevice *virtual_device,
                                uint32_t                   level,
                                uint32_t                   key_state)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   guint keysym, keycode, evcode;
 
@@ -528,8 +528,8 @@ apply_level_modifiers_in_impl (ClutterVirtualInputDevice *virtual_device,
               key_state == CLUTTER_KEY_STATE_PRESSED ? "press" : "release",
               evcode, virtual_device);
 
-  meta_seat_impl_notify_key_in_impl (virtual_evdev->seat->impl,
-				     virtual_evdev->impl_state->device,
+  meta_seat_impl_notify_key_in_impl (virtual_native->seat->impl,
+				     virtual_native->impl_state->device,
 				     time_us,
 				     evcode,
 				     key_state,
@@ -539,11 +539,11 @@ apply_level_modifiers_in_impl (ClutterVirtualInputDevice *virtual_device,
 static gboolean
 notify_keyval_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
   ClutterVirtualInputDevice *virtual_device =
-    CLUTTER_VIRTUAL_INPUT_DEVICE (virtual_evdev);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+    CLUTTER_VIRTUAL_INPUT_DEVICE (virtual_native);
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventKey *event = g_task_get_task_data (task);
   int key_count;
   guint keycode = 0, level = 0, evcode = 0;
@@ -567,13 +567,13 @@ notify_keyval_in_impl (GTask *task)
       goto out;
     }
 
-  key_count = update_button_count_in_impl (virtual_evdev, evcode, event->key_state);
+  key_count = update_button_count_in_impl (virtual_native, evcode, event->key_state);
   if (key_count < 0 || key_count > 1)
     {
       g_warning ("Received multiple virtual 0x%x key %s (ignoring)", evcode,
                  event->key_state == CLUTTER_KEY_STATE_PRESSED ?
                  "presses" : "releases");
-      update_button_count_in_impl (virtual_evdev, evcode, 1 - event->key_state);
+      update_button_count_in_impl (virtual_native, evcode, 1 - event->key_state);
       goto out;
     }
 
@@ -581,7 +581,7 @@ notify_keyval_in_impl (GTask *task)
               "Emitting virtual key-%s of key 0x%x with modifier level %d, "
               "press count %d (device %p)",
               event->key_state == CLUTTER_KEY_STATE_PRESSED ? "press" : "release",
-              evcode, level, key_count, virtual_evdev);
+              evcode, level, key_count, virtual_native);
 
   if (event->key_state)
     {
@@ -590,7 +590,7 @@ notify_keyval_in_impl (GTask *task)
     }
 
   meta_seat_impl_notify_key_in_impl (seat,
-                                     virtual_evdev->impl_state->device,
+                                     virtual_native->impl_state->device,
                                      event->time_us,
                                      evcode,
                                      event->key_state,
@@ -614,11 +614,11 @@ meta_virtual_input_device_native_notify_keyval (ClutterVirtualInputDevice *virtu
                                                 ClutterKeyState            key_state)
 {
   MetaVirtualEventKey *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventKey, 1);
   event->time_us = time_us;
@@ -627,7 +627,7 @@ meta_virtual_input_device_native_notify_keyval (ClutterVirtualInputDevice *virtu
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_keyval_in_impl);
   g_object_unref (task);
 }
@@ -664,9 +664,9 @@ direction_to_discrete (ClutterScrollDirection direction,
 static gboolean
 notify_discrete_scroll_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventScroll *event = g_task_get_task_data (task);
   double discrete_dx = 0.0, discrete_dy = 0.0;
 
@@ -676,7 +676,7 @@ notify_discrete_scroll_in_impl (GTask *task)
   direction_to_discrete (event->direction, &discrete_dx, &discrete_dy);
 
   meta_seat_impl_notify_discrete_scroll_in_impl (seat,
-                                                 virtual_evdev->impl_state->device,
+                                                 virtual_native->impl_state->device,
                                                  event->time_us,
                                                  discrete_dx * 120.0,
                                                  discrete_dy * 120.0,
@@ -693,11 +693,11 @@ meta_virtual_input_device_native_notify_discrete_scroll (ClutterVirtualInputDevi
                                                          ClutterScrollSource        scroll_source)
 {
   MetaVirtualEventScroll *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventScroll, 1);
   event->time_us = time_us;
@@ -706,7 +706,7 @@ meta_virtual_input_device_native_notify_discrete_scroll (ClutterVirtualInputDevi
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_discrete_scroll_in_impl);
   g_object_unref (task);
 }
@@ -714,9 +714,9 @@ meta_virtual_input_device_native_notify_discrete_scroll (ClutterVirtualInputDevi
 static gboolean
 notify_scroll_continuous_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventScroll *event = g_task_get_task_data (task);
 
   if (event->time_us == CLUTTER_CURRENT_TIME)
@@ -725,7 +725,7 @@ notify_scroll_continuous_in_impl (GTask *task)
   if (event->scroll_source == CLUTTER_SCROLL_SOURCE_WHEEL)
     {
       meta_seat_impl_notify_discrete_scroll_in_impl (seat,
-                                                     virtual_evdev->impl_state->device,
+                                                     virtual_native->impl_state->device,
                                                      event->time_us,
                                                      event->dx * (120.0 / 10.0),
                                                      event->dy * (120.0 / 10.0),
@@ -734,11 +734,11 @@ notify_scroll_continuous_in_impl (GTask *task)
   else
     {
       meta_seat_impl_notify_scroll_continuous_in_impl (seat,
-                                                       virtual_evdev->impl_state->device,
+                                                       virtual_native->impl_state->device,
                                                        event->time_us,
                                                        event->dx, event->dy,
                                                        event->scroll_source,
-                                                       CLUTTER_SCROLL_FINISHED_NONE);
+                                                       event->finish_flags);
     }
 
   g_task_return_boolean (task, TRUE);
@@ -754,11 +754,11 @@ meta_virtual_input_device_native_notify_scroll_continuous (ClutterVirtualInputDe
                                                            ClutterScrollFinishFlags   finish_flags)
 {
   MetaVirtualEventScroll *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventScroll, 1);
   event->time_us = time_us;
@@ -769,7 +769,7 @@ meta_virtual_input_device_native_notify_scroll_continuous (ClutterVirtualInputDe
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_scroll_continuous_in_impl);
   g_object_unref (task);
 }
@@ -777,9 +777,9 @@ meta_virtual_input_device_native_notify_scroll_continuous (ClutterVirtualInputDe
 static gboolean
 notify_touch_down_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventTouch *event = g_task_get_task_data (task);
   MetaTouchState *touch_state;
 
@@ -795,7 +795,7 @@ notify_touch_down_in_impl (GTask *task)
   touch_state->coords.y = (float) event->y;
 
   meta_seat_impl_notify_touch_event_in_impl (seat,
-                                             virtual_evdev->impl_state->device,
+                                             virtual_native->impl_state->device,
                                              CLUTTER_TOUCH_BEGIN,
                                              event->time_us,
                                              touch_state->seat_slot,
@@ -815,21 +815,21 @@ meta_virtual_input_device_native_notify_touch_down (ClutterVirtualInputDevice *v
                                                     double                     y)
 {
   MetaVirtualEventTouch *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventTouch, 1);
   event->time_us = time_us;
-  event->device_slot = virtual_evdev->slot_base + (guint) device_slot;
+  event->device_slot = virtual_native->slot_base + (guint) device_slot;
   event->x = x;
   event->y = y;
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_touch_down_in_impl);
   g_object_unref (task);
 }
@@ -837,9 +837,9 @@ meta_virtual_input_device_native_notify_touch_down (ClutterVirtualInputDevice *v
 static gboolean
 notify_touch_motion_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventTouch *event = g_task_get_task_data (task);
   MetaTouchState *touch_state;
 
@@ -855,7 +855,7 @@ notify_touch_motion_in_impl (GTask *task)
   touch_state->coords.y = (float) event->y;
 
   meta_seat_impl_notify_touch_event_in_impl (seat,
-                                             virtual_evdev->impl_state->device,
+                                             virtual_native->impl_state->device,
                                              CLUTTER_TOUCH_UPDATE,
                                              event->time_us,
                                              touch_state->seat_slot,
@@ -875,21 +875,21 @@ meta_virtual_input_device_native_notify_touch_motion (ClutterVirtualInputDevice
                                                       double                     y)
 {
   MetaVirtualEventTouch *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventTouch, 1);
   event->time_us = time_us;
-  event->device_slot = virtual_evdev->slot_base + (guint) device_slot;
+  event->device_slot = virtual_native->slot_base + (guint) device_slot;
   event->x = x;
   event->y = y;
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_touch_motion_in_impl);
   g_object_unref (task);
 }
@@ -897,9 +897,9 @@ meta_virtual_input_device_native_notify_touch_motion (ClutterVirtualInputDevice
 static gboolean
 notify_touch_up_in_impl (GTask *task)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat = virtual_native->seat->impl;
   MetaVirtualEventTouch *event = g_task_get_task_data (task);
   MetaTouchState *touch_state;
 
@@ -912,14 +912,14 @@ notify_touch_up_in_impl (GTask *task)
     goto out;
 
   meta_seat_impl_notify_touch_event_in_impl (seat,
-                                             virtual_evdev->impl_state->device,
+                                             virtual_native->impl_state->device,
                                              CLUTTER_TOUCH_END,
                                              event->time_us,
                                              touch_state->seat_slot,
                                              touch_state->coords.x,
                                              touch_state->coords.y);
 
-  meta_seat_impl_release_touch_state_in_impl (virtual_evdev->seat->impl,
+  meta_seat_impl_release_touch_state_in_impl (virtual_native->seat->impl,
                                               touch_state->seat_slot);
 
  out:
@@ -933,19 +933,19 @@ meta_virtual_input_device_native_notify_touch_up (ClutterVirtualInputDevice *vir
                                                   int                        device_slot)
 {
   MetaVirtualEventTouch *event;
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (virtual_device);
   GTask *task;
 
-  g_return_if_fail (virtual_evdev->impl_state != NULL);
+  g_return_if_fail (virtual_native->impl_state != NULL);
 
   event = g_new0 (MetaVirtualEventTouch, 1);
   event->time_us = time_us;
-  event->device_slot = virtual_evdev->slot_base + (guint) device_slot;
+  event->device_slot = virtual_native->slot_base + (guint) device_slot;
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
   g_task_set_task_data (task, event, g_free);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) notify_touch_up_in_impl);
   g_object_unref (task);
 }
@@ -956,16 +956,16 @@ meta_virtual_input_device_native_get_property (GObject    *object,
                                                GValue     *value,
                                                GParamSpec *pspec)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (object);
 
   switch (prop_id)
     {
     case PROP_SEAT:
-      g_value_set_pointer (value, virtual_evdev->seat);
+      g_value_set_pointer (value, virtual_native->seat);
       break;
     case PROP_SLOT_BASE:
-      g_value_set_uint (value, virtual_evdev->slot_base);
+      g_value_set_uint (value, virtual_native->slot_base);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -979,16 +979,16 @@ meta_virtual_input_device_native_set_property (GObject      *object,
                                                const GValue *value,
                                                GParamSpec   *pspec)
 {
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (object);
 
   switch (prop_id)
     {
     case PROP_SEAT:
-      virtual_evdev->seat = g_value_get_pointer (value);
+      virtual_native->seat = g_value_get_pointer (value);
       break;
     case PROP_SLOT_BASE:
-      virtual_evdev->slot_base = g_value_get_uint (value);
+      virtual_native->slot_base = g_value_get_uint (value);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1000,11 +1000,11 @@ static gboolean
 create_device_in_impl (GTask *task)
 {
   ImplState *impl_state = g_task_get_task_data (task);
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     g_task_get_source_object (task);
-  MetaSeatImpl *seat_impl = virtual_evdev->seat->impl;
+  MetaSeatImpl *seat_impl = virtual_native->seat->impl;
   ClutterVirtualInputDevice *virtual_device =
-    CLUTTER_VIRTUAL_INPUT_DEVICE (virtual_evdev);
+    CLUTTER_VIRTUAL_INPUT_DEVICE (virtual_native);
   ClutterInputDeviceType device_type =
     clutter_virtual_input_device_get_device_type (virtual_device);
 
@@ -1024,7 +1024,7 @@ meta_virtual_input_device_native_constructed (GObject *object)
 {
   ClutterVirtualInputDevice *virtual_device =
     CLUTTER_VIRTUAL_INPUT_DEVICE (object);
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (object);
   ClutterInputDeviceType device_type;
   g_autoptr (GTask) task = NULL;
@@ -1035,11 +1035,11 @@ meta_virtual_input_device_native_constructed (GObject *object)
               "Creating new virtual input device of type %d (%p)",
               device_type, virtual_device);
 
-  virtual_evdev->impl_state = g_new0 (ImplState, 1);
+  virtual_native->impl_state = g_new0 (ImplState, 1);
 
   task = g_task_new (virtual_device, NULL, NULL, NULL);
-  g_task_set_task_data (task, virtual_evdev->impl_state, NULL);
-  meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+  g_task_set_task_data (task, virtual_native->impl_state, NULL);
+  meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                  (GSourceFunc) create_device_in_impl);
 }
 
@@ -1055,27 +1055,27 @@ meta_virtual_input_device_native_dispose (GObject *object)
 {
   ClutterVirtualInputDevice *virtual_device =
     CLUTTER_VIRTUAL_INPUT_DEVICE (object);
-  MetaVirtualInputDeviceNative *virtual_evdev =
+  MetaVirtualInputDeviceNative *virtual_native =
     META_VIRTUAL_INPUT_DEVICE_NATIVE (object);
   GObjectClass *object_class =
     G_OBJECT_CLASS (meta_virtual_input_device_native_parent_class);
 
-  if (virtual_evdev->impl_state)
+  if (virtual_native->impl_state)
     {
       GTask *task;
 
       task = g_task_new (virtual_device, NULL, NULL, NULL);
-      g_task_set_task_data (task, virtual_evdev->impl_state,
+      g_task_set_task_data (task, virtual_native->impl_state,
                             (GDestroyNotify) impl_state_free);
-      meta_seat_impl_run_input_task (virtual_evdev->seat->impl, task,
+      meta_seat_impl_run_input_task (virtual_native->seat->impl, task,
                                      (GSourceFunc) release_device_in_impl);
       g_object_unref (task);
 
-      virtual_evdev->impl_state = NULL;
+      virtual_native->impl_state = NULL;
     }
 
-  meta_seat_native_release_touch_slots (virtual_evdev->seat,
-                                        virtual_evdev->slot_base);
+  meta_seat_native_release_touch_slots (virtual_native->seat,
+                                        virtual_native->slot_base);
 
   object_class->dispose (object);
 }
