@@ -32,7 +32,7 @@
 #include "compositor/meta-shaped-texture-private.h"
 #include "compositor/meta-window-actor-private.h"
 #include "core/window-private.h"
-#include "meta/meta-x11-errors.h"
+#include "mtk/mtk-x11.h"
 #include "x11/meta-x11-display-private.h"
 #include "x11/window-x11.h"
 
@@ -77,10 +77,10 @@ free_damage (MetaSurfaceActorX11 *self)
 
   xdisplay = meta_x11_display_get_xdisplay (display->x11_display);
 
-  meta_x11_error_trap_push (display->x11_display);
+  mtk_x11_error_trap_push (xdisplay);
   XDamageDestroy (xdisplay, self->damage);
   self->damage = None;
-  meta_x11_error_trap_pop (display->x11_display);
+  mtk_x11_error_trap_pop (xdisplay);
 }
 
 static void
@@ -88,6 +88,10 @@ detach_pixmap (MetaSurfaceActorX11 *self)
 {
   MetaDisplay *display = self->display;
   MetaShapedTexture *stex = meta_surface_actor_get_texture (META_SURFACE_ACTOR (self));
+  MetaContext *context = meta_display_get_context (display);
+  MetaBackend *backend = meta_context_get_backend (context);
+  ClutterBackend *clutter_backend = meta_backend_get_clutter_backend (backend);
+  CoglContext *cogl_context = clutter_backend_get_cogl_context (clutter_backend);
   Display *xdisplay;
 
   if (self->pixmap == None)
@@ -100,12 +104,12 @@ detach_pixmap (MetaSurfaceActorX11 *self)
    * pixmap, but it certainly doesn't work with current DRI/Mesa
    */
   meta_shaped_texture_set_texture (stex, NULL);
-  cogl_flush ();
+  cogl_context_flush (cogl_context);
 
-  meta_x11_error_trap_push (display->x11_display);
+  mtk_x11_error_trap_push (xdisplay);
   XFreePixmap (xdisplay, self->pixmap);
   self->pixmap = None;
-  meta_x11_error_trap_pop (display->x11_display);
+  mtk_x11_error_trap_pop (xdisplay);
 
   g_clear_object (&self->texture);
 }
@@ -114,7 +118,10 @@ static void
 set_pixmap (MetaSurfaceActorX11 *self,
             Pixmap               pixmap)
 {
-  CoglContext *ctx = clutter_backend_get_cogl_context (clutter_get_default_backend ());
+  ClutterContext *clutter_context =
+    clutter_actor_get_context (CLUTTER_ACTOR (self));
+  ClutterBackend *backend = clutter_context_get_backend (clutter_context);
+  CoglContext *ctx = clutter_backend_get_cogl_context (backend);
   MetaShapedTexture *stex = meta_surface_actor_get_texture (META_SURFACE_ACTOR (self));
   GError *error = NULL;
   CoglTexture *cogl_texture;
@@ -122,7 +129,7 @@ set_pixmap (MetaSurfaceActorX11 *self,
   g_assert (self->pixmap == None);
   self->pixmap = pixmap;
 
-  cogl_texture = COGL_TEXTURE (cogl_texture_pixmap_x11_new (ctx, self->pixmap, FALSE, &error));
+  cogl_texture = cogl_texture_pixmap_x11_new (ctx, self->pixmap, FALSE, &error);
 
   if (error != NULL)
     {
@@ -153,10 +160,10 @@ update_pixmap (MetaSurfaceActorX11 *self)
       Pixmap new_pixmap;
       Window xwindow = meta_window_x11_get_toplevel_xwindow (self->window);
 
-      meta_x11_error_trap_push (display->x11_display);
+      mtk_x11_error_trap_push (xdisplay);
       new_pixmap = XCompositeNameWindowPixmap (xdisplay, xwindow);
 
-      if (meta_x11_error_trap_pop_with_return (display->x11_display) != Success)
+      if (mtk_x11_error_trap_pop_with_return (xdisplay) != Success)
         {
           /* Probably a BadMatch if the window isn't viewable; we could
            * GrabServer/GetWindowAttributes/NameWindowPixmap/UngrabServer/Sync
@@ -186,11 +193,8 @@ meta_surface_actor_x11_is_visible (MetaSurfaceActorX11 *self)
 }
 
 static void
-meta_surface_actor_x11_process_damage (MetaSurfaceActor *actor,
-                                       int               x,
-                                       int               y,
-                                       int               width,
-                                       int               height)
+meta_surface_actor_x11_process_damage (MetaSurfaceActor   *actor,
+                                       const MtkRectangle *area)
 {
   MetaSurfaceActorX11 *self = META_SURFACE_ACTOR_X11 (actor);
   CoglTexturePixmapX11 *pixmap;
@@ -202,10 +206,10 @@ meta_surface_actor_x11_process_damage (MetaSurfaceActor *actor,
       MtkRectangle window_rect;
       meta_window_get_frame_rect (self->window, &window_rect);
 
-      if (x == 0 &&
-          y == 0 &&
-          window_rect.width == width &&
-          window_rect.height == height)
+      if (area->x == 0 &&
+          area->y == 0 &&
+          window_rect.width == area->width &&
+          window_rect.height == area->height)
         self->full_damage_frames_count++;
       else
         self->full_damage_frames_count = 0;
@@ -222,8 +226,8 @@ meta_surface_actor_x11_process_damage (MetaSurfaceActor *actor,
     return;
 
   pixmap = COGL_TEXTURE_PIXMAP_X11 (meta_multi_texture_get_plane (self->texture, 0));
-  cogl_texture_pixmap_x11_update_area (pixmap, x, y, width, height);
-  meta_surface_actor_update_area (actor, x, y, width, height);
+  cogl_texture_pixmap_x11_update_area (pixmap, area);
+  meta_surface_actor_update_area (actor, area);
 }
 
 void
@@ -234,9 +238,9 @@ meta_surface_actor_x11_handle_updates (MetaSurfaceActorX11 *self)
 
   if (self->received_damage)
     {
-      meta_x11_error_trap_push (display->x11_display);
+      mtk_x11_error_trap_push (xdisplay);
       XDamageSubtract (xdisplay, self->damage, None, None);
-      meta_x11_error_trap_pop (display->x11_display);
+      mtk_x11_error_trap_pop (xdisplay);
 
       self->received_damage = FALSE;
     }
@@ -276,7 +280,7 @@ sync_unredirected (MetaSurfaceActorX11 *self)
   Display *xdisplay = meta_x11_display_get_xdisplay (display->x11_display);
   Window xwindow = meta_window_x11_get_toplevel_xwindow (self->window);
 
-  meta_x11_error_trap_push (display->x11_display);
+  mtk_x11_error_trap_push (xdisplay);
 
   if (self->unredirected)
     {
@@ -291,7 +295,7 @@ sync_unredirected (MetaSurfaceActorX11 *self)
       clutter_actor_queue_redraw (CLUTTER_ACTOR (self));
     }
 
-  meta_x11_error_trap_pop (display->x11_display);
+  mtk_x11_error_trap_pop (xdisplay);
 }
 
 void
@@ -316,10 +320,10 @@ release_x11_resources (MetaSurfaceActorX11 *self)
 {
   MetaX11Display *x11_display = meta_display_get_x11_display (self->display);
 
-  meta_x11_error_trap_push (x11_display);
+  mtk_x11_error_trap_push (x11_display->xdisplay);
   detach_pixmap (self);
   free_damage (self);
-  meta_x11_error_trap_pop (x11_display);
+  mtk_x11_error_trap_pop (x11_display->xdisplay);
 }
 
 static void
@@ -358,9 +362,9 @@ create_damage (MetaSurfaceActorX11 *self)
   Display *xdisplay = meta_x11_display_get_xdisplay (x11_display);
   Window xwindow = meta_window_x11_get_toplevel_xwindow (self->window);
 
-  meta_x11_error_trap_push (x11_display);
+  mtk_x11_error_trap_push (xdisplay);
   self->damage = XDamageCreate (xdisplay, xwindow, XDamageReportBoundingBox);
-  meta_x11_error_trap_pop (x11_display);
+  mtk_x11_error_trap_pop (xdisplay);
 }
 
 static void
@@ -415,6 +419,7 @@ meta_surface_actor_x11_new (MetaWindow *window)
   sync_unredirected (self);
 
   clutter_actor_set_reactive (CLUTTER_ACTOR (self), TRUE);
+  clutter_actor_set_accessible_name (CLUTTER_ACTOR (self), "X11 surface");
   return META_SURFACE_ACTOR (self);
 }
 
