@@ -25,6 +25,7 @@
 #include "compositor/meta-surface-actor-wayland.h"
 #include "compositor/meta-window-actor-wayland.h"
 #include "meta/meta-window-actor.h"
+#include "wayland/meta-wayland-actor-surface.h"
 #include "wayland/meta-wayland-buffer.h"
 #include "wayland/meta-wayland-single-pixel-buffer.h"
 #include "wayland/meta-wayland-surface-private.h"
@@ -73,6 +74,7 @@ surface_container_new (MetaWindowActor *window_actor)
   MetaSurfaceContainerActorWayland *surface_container;
 
   surface_container = g_object_new (META_TYPE_SURFACE_CONTAINER_ACTOR_WAYLAND,
+                                    "accessible-name", "Wayland surface container",
                                     NULL);
   surface_container->window_actor = window_actor;
 
@@ -255,9 +257,9 @@ meta_window_actor_wayland_rebuild_surface_tree (MetaWindowActor *actor)
 
       if (!g_list_find (surface_actors, child_actor))
         {
-          MetaSurfaceActor *surface_actor = META_SURFACE_ACTOR (child_actor);
+          MetaSurfaceActor *child_surface_actor = META_SURFACE_ACTOR (child_actor);
 
-          meta_window_actor_remove_surface_actor (actor, surface_actor);
+          meta_window_actor_remove_surface_actor (actor, child_surface_actor);
           clutter_actor_remove_child (CLUTTER_ACTOR (self->surface_container),
                                       child_actor);
         }
@@ -286,8 +288,8 @@ calculate_background_cull_region (MetaWindowActorWayland *self)
   rect = (MtkRectangle) {
     .x = 0,
     .y = 0,
-    .width = clutter_actor_get_width (self->background) * geometry_scale,
-    .height = clutter_actor_get_height (self->background) * geometry_scale,
+    .width = (int) (clutter_actor_get_width (self->background) * geometry_scale),
+    .height = (int) (clutter_actor_get_height (self->background) * geometry_scale),
   };
 
   return mtk_region_create_rectangle (&rect);
@@ -492,6 +494,21 @@ meta_window_actor_wayland_set_frozen (MetaWindowActor *actor,
   clutter_actor_iter_init (&iter, CLUTTER_ACTOR (self->surface_container));
   while (clutter_actor_iter_next (&iter, &child))
     meta_surface_actor_set_frozen (META_SURFACE_ACTOR (child), frozen);
+
+  if (!frozen)
+    {
+      MetaSurfaceActor *surface_actor = meta_window_actor_get_surface (actor);
+      MetaWaylandSurface *surface =
+        meta_surface_actor_wayland_get_surface (META_SURFACE_ACTOR_WAYLAND (surface_actor));
+
+      if (surface && surface->role)
+        {
+          MetaWaylandActorSurface *actor_surface =
+            META_WAYLAND_ACTOR_SURFACE (surface->role);
+
+          meta_wayland_actor_surface_sync_actor_state (actor_surface);
+        }
+    }
 }
 
 static void
@@ -599,7 +616,7 @@ do_sync_geometry (MetaWindowActorWayland *self)
         {
           self->background = clutter_actor_new ();
           clutter_actor_set_background_color (self->background,
-                                               &CLUTTER_COLOR_INIT (0, 0, 0, 255));
+                                              &COGL_COLOR_INIT (0, 0, 0, 255));
           clutter_actor_set_reactive (self->background, TRUE);
           clutter_actor_insert_child_below (CLUTTER_ACTOR (self),
                                             self->background,
