@@ -329,7 +329,6 @@ on_monitors_changed (MetaMonitorManager *monitor_manager,
       uint8_t red;
       uint8_t green;
       uint8_t blue;
-      ClutterColor color;
 
       meta_display_get_monitor_geometry (display, i, &rect);
 
@@ -348,10 +347,10 @@ on_monitors_changed (MetaMonitorManager *monitor_manager,
       blue = g_rand_int_range (rand, 0, 255);
       green = g_rand_int_range (rand, 0, 255);
       red = g_rand_int_range (rand, 0, 255);
-      clutter_color_init (&color, red, green, blue, 255);
 
       background = meta_background_new (display);
-      meta_background_set_color (background, &color);
+      meta_background_set_color (background,
+                                 &COGL_COLOR_INIT (red, green, blue, 255));
       meta_background_content_set_background (background_content, background);
       g_object_unref (background);
 
@@ -494,7 +493,9 @@ switch_workspace (MetaPlugin *plugin,
                          &screen_height);
 
   workspace1 = clutter_actor_new ();
+  clutter_actor_set_accessible_name (workspace1, "Workspace 1");
   workspace2 = clutter_actor_new ();
+  clutter_actor_set_accessible_name (workspace2, "Workspace 2");
 
   clutter_actor_set_pivot_point (workspace1, 1.0, 1.0);
   clutter_actor_set_size (workspace1,
@@ -825,7 +826,7 @@ get_display_tile_preview (MetaDisplay *display)
       preview = g_new0 (DisplayTilePreview, 1);
 
       preview->actor = clutter_actor_new ();
-      clutter_actor_set_background_color (preview->actor, &CLUTTER_COLOR_INIT (0, 0, 255, 255));
+      clutter_actor_set_background_color (preview->actor, &COGL_COLOR_INIT (0, 0, 255, 255));
       clutter_actor_set_opacity (preview->actor, 100);
 
       clutter_actor_add_child (meta_get_window_group_for_display (display), preview->actor);
