@@ -84,6 +84,32 @@ clutter_test_get_stage (void)
   return meta_backend_get_stage (backend);
 }
 
+ClutterContext *
+clutter_test_get_context (void)
+{
+  MetaContext *context = test_environ->context;
+  MetaBackend *backend = meta_context_get_backend (context);
+
+  return meta_backend_get_clutter_context (backend);
+}
+
+ClutterBackend *
+clutter_test_get_backend (void)
+{
+  MetaContext *context = test_environ->context;
+  MetaBackend *backend = meta_context_get_backend (context);
+
+  return meta_backend_get_clutter_backend (backend);
+}
+
+ClutterSeat *
+clutter_test_get_default_seat (void)
+{
+  ClutterBackend *backend = clutter_test_get_backend ();
+
+  return clutter_backend_get_default_seat (backend);
+}
+
 void
 clutter_test_flush_input (void)
 {
@@ -193,8 +219,9 @@ clutter_test_add_data (const char    *test_path,
 /**
  * clutter_test_add_data_full:
  * @test_path: unique path for identifying the test
- * @test_func: (scope notified): function containing the test
- * @test_data: (closure): data to pass to the test function
+ * @test_func: (scope notified) (closure test_data): function
+ *             containing the test
+ * @test_data: data to pass to the test function
  * @test_notify: function called when the test function ends
  *
  * Adds a test unit to the Clutter test environment.
