@@ -169,11 +169,11 @@ button_press_cb (ClutterActor *actor,
 static void
 make_ui (ClutterActor *stage)
 {
-  ClutterColor  color_stage = { 0x00, 0x00, 0x00, 0xff };
-  ClutterColor  color_text  = { 0xff, 0x00, 0x00, 0xff };
-  ClutterColor  color_sel   = { 0x00, 0xff, 0x00, 0x55 };
-  ClutterColor  color_rect  = { 0x00, 0xff, 0xff, 0xff };
-  ClutterColor  color_label = { 0x00, 0x00, 0x00, 0xff };
+  CoglColor color_stage = { 0x00, 0x00, 0x00, 0xff };
+  CoglColor color_text = { 0xff, 0x00, 0x00, 0xff };
+  CoglColor color_sel = { 0x00, 0xff, 0x00, 0x55 };
+  CoglColor color_rect = { 0x00, 0xff, 0xff, 0xff };
+  CoglColor color_label = { 0x00, 0x00, 0x00, 0xff };
   ClutterActor *button      = NULL;
   ClutterActor *rectangle   = NULL;
   ClutterActor *label       = NULL;
@@ -235,7 +235,6 @@ main (int argc, char *argv[])
   cally_util_a11y_init (&argc, &argv);
 
   stage = clutter_test_get_stage ();
-  clutter_stage_set_title (CLUTTER_STAGE (stage), "Cally - AtkText Test");
   g_signal_connect (stage, "destroy", G_CALLBACK (clutter_test_quit), NULL);
 
   make_ui (stage);
