@@ -42,7 +42,7 @@ solid_content_paint_content (ClutterContent      *content,
 {
   SolidContent *self = (SolidContent *) content;
   ClutterActorBox box, content_box;
-  ClutterColor color;
+  CoglColor color;
   PangoLayout *layout;
   PangoRectangle logical;
   ClutterPaintNode *node;
@@ -67,20 +67,20 @@ solid_content_paint_content (ClutterContent      *content,
   box.x2 -= self->padding;
   box.y2 -= self->padding;
 
-  color.alpha = self->alpha * 255;
+  color.alpha = (uint8_t) (self->alpha * 255);
 
-  color.red = self->red * 255;
-  color.green = self->green * 255;
-  color.blue = self->blue * 255;
+  color.red = (uint8_t) (self->red * 255);
+  color.green = (uint8_t) (self->green * 255);
+  color.blue = (uint8_t) (self->blue * 255);
 
   node = clutter_color_node_new (&color);
   clutter_paint_node_add_rectangle (node, &box);
   clutter_paint_node_add_child (root, node);
   clutter_paint_node_unref (node);
 
-  color.red = (1.0 - self->red) * 255;
-  color.green = (1.0 - self->green) * 255;
-  color.blue = (1.0 - self->blue) * 255;
+  color.red = (uint8_t) ((1.0 - self->red) * 255);
+  color.green = (uint8_t) ((1.0 - self->green) * 255);
+  color.blue = (uint8_t) ((1.0 - self->blue) * 255);
 
   layout = clutter_actor_create_pango_layout (actor, "A");
   pango_layout_get_pixel_extents (layout, NULL, &logical);
@@ -125,9 +125,9 @@ solid_content_paint_content (ClutterContent      *content,
 
   /* center */
   box.x1 = clutter_actor_box_get_x (&content_box)
-         + (clutter_actor_box_get_width (&content_box) - logical.width) / 2.0;
+         + (clutter_actor_box_get_width (&content_box) - logical.width) / 2.0f;
   box.y1 = clutter_actor_box_get_y (&content_box)
-         + (clutter_actor_box_get_height (&content_box) - logical.height) / 2.0;
+         + (clutter_actor_box_get_height (&content_box) - logical.height) / 2.0f;
   box.x2 = box.x1 + logical.width;
   box.y2 = box.y1 + logical.height;
   clutter_paint_node_add_rectangle (node, &box);
@@ -190,7 +190,6 @@ test_image_main (int argc, char *argv[])
 
   stage = clutter_test_get_stage ();
   clutter_actor_set_name (stage, "Stage");
-  clutter_stage_set_title (CLUTTER_STAGE (stage), "Content");
   g_signal_connect (stage, "destroy", G_CALLBACK (clutter_test_quit), NULL);
   clutter_actor_show (stage);
 
@@ -227,7 +226,7 @@ test_image_main (int argc, char *argv[])
   for (i = 0; i < n_rects; i++)
     {
       ClutterActor *box = clutter_actor_new ();
-      ClutterColor bg_color = {
+      CoglColor bg_color = {
         g_random_int_range (0, 255),
         g_random_int_range (0, 255),
         g_random_int_range (0, 255),
@@ -235,7 +234,7 @@ test_image_main (int argc, char *argv[])
       };
       char *name, *str;
 
-      str = clutter_color_to_string (&bg_color);
+      str = cogl_color_to_string (&bg_color);
       name = g_strconcat ("Box <", color, ">", NULL);
       clutter_actor_set_name (box, name);
 
