@@ -39,7 +39,6 @@
 #include <X11/Xatom.h>
 #include <X11/XKBlib.h>
 #include <X11/extensions/shape.h>
-#include <X11/Xcursor/Xcursor.h>
 #include <X11/extensions/Xcomposite.h>
 #include <X11/extensions/Xdamage.h>
 #include <X11/extensions/Xfixes.h>
@@ -53,14 +52,16 @@
 #include "backends/meta-settings-private.h"
 #include "backends/x11/meta-backend-x11.h"
 #include "backends/x11/meta-stage-x11.h"
-#include "core/frame.h"
 #include "core/meta-workspace-manager-private.h"
 #include "core/util-private.h"
 #include "core/workspace-private.h"
 #include "meta/main.h"
 #include "mtk/mtk-x11.h"
+#include "third_party/xcursor/xcursor.h"
 #include "x11/events.h"
 #include "x11/group-props.h"
+#include "x11/meta-x11-frame.h"
+#include "x11/meta-x11-keybindings-private.h"
 #include "x11/meta-x11-selection-private.h"
 #include "x11/window-props.h"
 #include "x11/window-x11.h"
@@ -70,7 +71,7 @@
 #include "wayland/meta-xwayland-private.h"
 #endif
 
-G_DEFINE_TYPE (MetaX11Display, meta_x11_display, G_TYPE_OBJECT)
+#include "meta-dbus-x11.h"
 
 static GQuark quark_x11_display_logical_monitor_data = 0;
 
@@ -89,6 +90,14 @@ typedef struct _MetaX11DisplayLogicalMonitorData
   int xinerama_index;
 } MetaX11DisplayLogicalMonitorData;
 
+typedef struct _MetaX11DisplayPrivate
+{
+  MetaDBusX11 *dbus_api;
+  guint dbus_name_id;
+} MetaX11DisplayPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (MetaX11Display, meta_x11_display, G_TYPE_OBJECT)
+
 static char *get_screen_name (Display *xdisplay,
                               int      number);
 
@@ -122,6 +131,42 @@ backend_from_x11_display (MetaX11Display *x11_display)
   return meta_context_get_backend (context);
 }
 
+static void
+stage_to_protocol (MetaX11Display *x11_display,
+                   int             stage_x,
+                   int             stage_y,
+                   int            *protocol_x,
+                   int            *protocol_y)
+{
+  MetaDisplay *display = meta_x11_display_get_display (x11_display);
+  MetaContext *context = meta_display_get_context (display);
+  int scale = 1;
+
+  switch (meta_context_get_compositor_type (context))
+    {
+    case META_COMPOSITOR_TYPE_WAYLAND:
+      {
+#ifdef HAVE_XWAYLAND
+        MetaWaylandCompositor *wayland_compositor =
+          meta_context_get_wayland_compositor (context);
+        MetaXWaylandManager *xwayland_manager =
+          &wayland_compositor->xwayland_manager;
+
+        scale = meta_xwayland_get_effective_scale (xwayland_manager);
+#endif
+        break;
+      }
+
+    case META_COMPOSITOR_TYPE_X11:
+      break;
+    }
+
+  if (protocol_x)
+    *protocol_x = stage_x * scale;
+  if (protocol_y)
+    *protocol_y = stage_y * scale;
+}
+
 static void
 meta_x11_display_unmanage_windows (MetaX11Display *x11_display)
 {
@@ -151,13 +196,68 @@ meta_x11_event_filter_free (MetaX11EventFilter *filter)
   g_free (filter);
 }
 
+static void
+on_bus_acquired (GDBusConnection *connection,
+                 const char      *name,
+                 gpointer         user_data)
+{
+  MetaX11Display *x11_display = user_data;
+  MetaX11DisplayPrivate *priv =
+    meta_x11_display_get_instance_private (x11_display);
+
+  g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (priv->dbus_api),
+                                    connection,
+                                    "/org/gnome/Mutter/X11",
+                                    NULL);
+}
+
+static void
+update_ui_scaling_factor (MetaX11Display *x11_display)
+{
+  MetaX11DisplayPrivate *priv =
+    meta_x11_display_get_instance_private (x11_display);
+  MetaBackend *backend = backend_from_x11_display (x11_display);
+  MetaContext *context = meta_backend_get_context (backend);
+  int ui_scaling_factor = 1;
+
+  switch (meta_context_get_compositor_type (context))
+    {
+    case META_COMPOSITOR_TYPE_WAYLAND:
+      {
+#ifdef HAVE_XWAYLAND
+        MetaWaylandCompositor *wayland_compositor =
+          meta_context_get_wayland_compositor (context);
+        MetaXWaylandManager *xwayland_manager =
+          &wayland_compositor->xwayland_manager;
+
+        ui_scaling_factor = meta_xwayland_get_x11_ui_scaling_factor (xwayland_manager);
+#endif
+        break;
+      }
+    case META_COMPOSITOR_TYPE_X11:
+      {
+        MetaSettings *settings = meta_backend_get_settings (backend);
+
+        ui_scaling_factor = meta_settings_get_ui_scaling_factor (settings);
+        break;
+      }
+    }
+
+  meta_dbus_x11_set_ui_scaling_factor (priv->dbus_api, ui_scaling_factor);
+}
+
 static void
 meta_x11_display_dispose (GObject *object)
 {
   MetaX11Display *x11_display = META_X11_DISPLAY (object);
+  MetaX11DisplayPrivate *priv =
+    meta_x11_display_get_instance_private (x11_display);
 
   x11_display->closing = TRUE;
 
+  g_clear_handle_id (&priv->dbus_name_id, g_bus_unown_name);
+  g_clear_object (&priv->dbus_api);
+
   g_clear_pointer (&x11_display->alarm_filters, g_ptr_array_unref);
 
   g_clear_list (&x11_display->event_funcs,
@@ -177,11 +277,11 @@ meta_x11_display_dispose (GObject *object)
       g_clear_object (&x11_display->frames_client);
     }
 
-  if (x11_display->empty_region != None)
+  if (x11_display->stage_input_region != None)
     {
       XFixesDestroyRegion (x11_display->xdisplay,
-                           x11_display->empty_region);
-      x11_display->empty_region = None;
+                           x11_display->stage_input_region);
+      x11_display->stage_input_region = None;
     }
 
   meta_x11_startup_notification_release (x11_display);
@@ -306,8 +406,32 @@ static void
 on_x11_display_opened (MetaX11Display *x11_display,
                        MetaDisplay    *display)
 {
+  Window old_active_xwindow = None;
+
+  if (!meta_is_wayland_compositor ())
+    {
+      meta_prop_get_window (display->x11_display,
+                            display->x11_display->xroot,
+                            display->x11_display->atom__NET_ACTIVE_WINDOW,
+                            &old_active_xwindow);
+    }
+
   meta_display_manage_all_xwindows (display);
-  meta_x11_display_redirect_windows (x11_display, display);
+
+  if (old_active_xwindow != None)
+    {
+      MetaWindow *old_active_window;
+
+      old_active_window = meta_x11_display_lookup_x_window (x11_display,
+                                                            old_active_xwindow);
+      if (old_active_window)
+        {
+          uint32_t timestamp;
+
+          timestamp = display->x11_display->timestamp;
+          meta_window_focus (old_active_window, timestamp);
+        }
+    }
 }
 
 static void
@@ -572,6 +696,9 @@ set_desktop_geometry_hint (MetaX11Display *x11_display)
     return;
 
   meta_display_get_size (x11_display->display, &monitor_width, &monitor_height);
+  stage_to_protocol (x11_display,
+                     monitor_width, monitor_height,
+                     &monitor_width, &monitor_height);
 
   data[0] = monitor_width;
   data[1] = monitor_height;
@@ -981,14 +1108,22 @@ set_workspace_work_area_hint (MetaWorkspace  *workspace,
 
   for (l = logical_monitors; l; l = l->next)
     {
-      MtkRectangle area;
+      MtkRectangle stage_area;
+      MtkRectangle protocol_area;
 
-      meta_workspace_get_work_area_for_logical_monitor (workspace, l->data, &area);
+      meta_workspace_get_work_area_for_logical_monitor (workspace, l->data,
+                                                        &stage_area);
 
-      tmp[0] = area.x;
-      tmp[1] = area.y;
-      tmp[2] = area.width;
-      tmp[3] = area.height;
+      stage_to_protocol (x11_display,
+                         stage_area.x, stage_area.y,
+                         &protocol_area.x, &protocol_area.y);
+      stage_to_protocol (x11_display,
+                         stage_area.width, stage_area.height,
+                         &protocol_area.width, &protocol_area.height);
+      tmp[0] = protocol_area.x;
+      tmp[1] = protocol_area.y;
+      tmp[2] = protocol_area.width;
+      tmp[3] = protocol_area.height;
 
       tmp += 4;
     }
@@ -1017,7 +1152,6 @@ set_work_area_hint (MetaDisplay    *display,
   int num_workspaces;
   GList *l;
   unsigned long *data, *tmp;
-  MtkRectangle area;
 
   num_workspaces = meta_workspace_manager_get_n_workspaces (workspace_manager);
   data = g_new (unsigned long, num_workspaces * 4);
@@ -1026,14 +1160,22 @@ set_work_area_hint (MetaDisplay    *display,
   for (l = workspace_manager->workspaces; l; l = l->next)
     {
       MetaWorkspace *workspace = l->data;
+      MtkRectangle stage_area;
+      MtkRectangle protocol_area;
 
-      meta_workspace_get_work_area_all_monitors (workspace, &area);
+      meta_workspace_get_work_area_all_monitors (workspace, &stage_area);
       set_workspace_work_area_hint (workspace, x11_display);
 
-      tmp[0] = area.x;
-      tmp[1] = area.y;
-      tmp[2] = area.width;
-      tmp[3] = area.height;
+      stage_to_protocol (x11_display,
+                         stage_area.x, stage_area.y,
+                         &protocol_area.x, &protocol_area.y);
+      stage_to_protocol (x11_display,
+                         stage_area.width, stage_area.height,
+                         &protocol_area.width, &protocol_area.height);
+      tmp[0] = protocol_area.x;
+      tmp[1] = protocol_area.y;
+      tmp[2] = protocol_area.width;
+      tmp[3] = protocol_area.height;
 
       tmp += 4;
     }
@@ -1196,6 +1338,58 @@ meta_x11_display_init_frames_client (MetaX11Display *x11_display)
                            on_frames_client_died, x11_display);
 }
 
+static void
+initialize_dbus_interface (MetaX11Display *x11_display)
+{
+  MetaX11DisplayPrivate *priv =
+    meta_x11_display_get_instance_private (x11_display);
+
+  priv->dbus_api = meta_dbus_x11_skeleton_new ();
+  priv->dbus_name_id =
+    g_bus_own_name (G_BUS_TYPE_SESSION,
+                    "org.gnome.Mutter.X11",
+                    G_BUS_NAME_OWNER_FLAGS_NONE,
+                    on_bus_acquired,
+                    NULL, NULL,
+                    x11_display, NULL);
+  update_ui_scaling_factor (x11_display);
+}
+
+static void
+experimental_features_changed (MetaSettings           *settings,
+                               MetaExperimentalFeature old_experimental_features,
+                               MetaX11Display         *x11_display)
+{
+  gboolean was_xwayland_native_scaling;
+  gboolean was_stage_views_scaled;
+  gboolean is_xwayland_native_scaling;
+  gboolean is_stage_views_scaled;
+
+  was_xwayland_native_scaling =
+    !!(old_experimental_features &
+       META_EXPERIMENTAL_FEATURE_XWAYLAND_NATIVE_SCALING);
+  was_stage_views_scaled =
+    !!(old_experimental_features &
+       META_EXPERIMENTAL_FEATURE_SCALE_MONITOR_FRAMEBUFFER);
+
+  is_xwayland_native_scaling =
+    meta_settings_is_experimental_feature_enabled (
+      settings,
+      META_EXPERIMENTAL_FEATURE_XWAYLAND_NATIVE_SCALING);
+  is_stage_views_scaled =
+    meta_settings_is_experimental_feature_enabled (
+      settings,
+      META_EXPERIMENTAL_FEATURE_SCALE_MONITOR_FRAMEBUFFER);
+
+  if (is_xwayland_native_scaling != was_xwayland_native_scaling ||
+      is_stage_views_scaled != was_stage_views_scaled)
+    {
+      update_ui_scaling_factor (x11_display);
+      set_desktop_geometry_hint (x11_display);
+      set_work_area_hint (x11_display->display, x11_display);
+    }
+}
+
 /**
  * meta_x11_display_new:
  *
@@ -1214,6 +1408,7 @@ meta_x11_display_new (MetaDisplay  *display,
   MetaBackend *backend = meta_context_get_backend (context);
   MetaMonitorManager *monitor_manager =
     meta_backend_get_monitor_manager (backend);
+  MetaSettings *settings = meta_backend_get_settings (backend);
   g_autoptr (MetaX11Display) x11_display = NULL;
   Display *xdisplay;
   Screen *xscreen;
@@ -1241,7 +1436,9 @@ meta_x11_display_new (MetaDisplay  *display,
   if (!xdisplay)
     return NULL;
 
+#ifdef HAVE_X11
   XSynchronize (xdisplay, meta_context_is_x11_sync (context));
+#endif
 
 #ifdef HAVE_XWAYLAND
   if (meta_is_wayland_compositor ())
@@ -1290,6 +1487,8 @@ meta_x11_display_new (MetaDisplay  *display,
   x11_display = g_object_new (META_TYPE_X11_DISPLAY, NULL);
   x11_display->display = display;
 
+  initialize_dbus_interface (x11_display);
+
   /* here we use XDisplayName which is what the user
    * probably put in, vs. DisplayString(display) which is
    * canonicalized by XOpenDisplay()
@@ -1339,9 +1538,8 @@ meta_x11_display_new (MetaDisplay  *display,
                            x11_display,
                            G_CONNECT_SWAPPED);
 
-#ifdef HAVE_XWAYLAND
+#ifdef HAVE_X11
   if (!meta_is_wayland_compositor ())
-#endif
     {
       ClutterStage *stage =
         CLUTTER_STAGE (meta_get_stage_for_display (display));
@@ -1352,6 +1550,7 @@ meta_x11_display_new (MetaDisplay  *display,
                                x11_display,
                                G_CONNECT_SWAPPED);
     }
+#endif
 
   x11_display->xids = g_hash_table_new (meta_unsigned_long_hash,
                                         meta_unsigned_long_equal);
@@ -1382,7 +1581,7 @@ meta_x11_display_new (MetaDisplay  *display,
                            "monitors-changed-internal",
                            G_CALLBACK (on_monitors_changed_internal),
                            x11_display,
-                           0);
+                           G_CONNECT_AFTER);
 
   init_leader_window (x11_display, &timestamp);
   x11_display->timestamp = timestamp;
@@ -1475,6 +1674,11 @@ meta_x11_display_new (MetaDisplay  *display,
 
   meta_prefs_add_listener (prefs_changed_callback, x11_display);
 
+  g_signal_connect_object (settings,
+                           "experimental-features-changed",
+                           G_CALLBACK (experimental_features_changed),
+                           x11_display, 0);
+
   set_work_area_hint (display, x11_display);
 
   g_signal_connect_object (display, "workareas-changed",
@@ -1688,16 +1892,12 @@ meta_x11_display_reload_cursor (MetaX11Display *x11_display)
 }
 
 static void
-set_cursor_theme (Display     *xdisplay,
-                  MetaBackend *backend)
+set_cursor_theme (Display    *xdisplay,
+                  const char *theme,
+                  int         size)
 {
-  MetaSettings *settings = meta_backend_get_settings (backend);
-  int scale;
-
-  scale = meta_settings_get_ui_scaling_factor (settings);
-  XcursorSetTheme (xdisplay, meta_prefs_get_cursor_theme ());
-  XcursorSetDefaultSize (xdisplay,
-                         meta_prefs_get_cursor_size () * scale);
+  XcursorSetTheme (xdisplay, theme);
+  XcursorSetDefaultSize (xdisplay, size);
 }
 
 static void
@@ -1749,18 +1949,49 @@ static void
 update_cursor_theme (MetaX11Display *x11_display)
 {
   MetaBackend *backend = backend_from_x11_display (x11_display);
+  MetaContext *context = meta_backend_get_context (backend);
+  MetaSettings *settings = meta_backend_get_settings (backend);
+  int scale = 1;
+  int size;
+  const char *theme;
 
-  set_cursor_theme (x11_display->xdisplay, backend);
+  switch (meta_context_get_compositor_type (context))
+    {
+    case META_COMPOSITOR_TYPE_WAYLAND:
+      {
+#ifdef HAVE_XWAYLAND
+        MetaWaylandCompositor *wayland_compositor =
+          meta_context_get_wayland_compositor (context);
+        MetaXWaylandManager *xwayland_manager =
+          &wayland_compositor->xwayland_manager;
+
+        scale = meta_xwayland_get_x11_ui_scaling_factor (xwayland_manager);
+#endif
+        break;
+      }
+
+    case META_COMPOSITOR_TYPE_X11:
+      scale = meta_settings_get_ui_scaling_factor (settings);
+      break;
+    }
+
+  size = meta_prefs_get_cursor_size () * scale;
+
+  theme = meta_prefs_get_cursor_theme ();
+
+  set_cursor_theme (x11_display->xdisplay, theme, size);
   schedule_reload_x11_cursor (x11_display);
 
+#ifdef HAVE_X11
   if (META_IS_BACKEND_X11 (backend))
     {
       MetaBackendX11 *backend_x11 = META_BACKEND_X11 (backend);
       Display *xdisplay = meta_backend_x11_get_xdisplay (backend_x11);
 
-      set_cursor_theme (xdisplay, backend);
+      set_cursor_theme (xdisplay, theme, size);
       meta_backend_x11_reload_cursor (backend_x11);
     }
+#endif
 }
 
 MetaWindow *
@@ -1882,27 +2113,27 @@ create_guard_window (MetaX11Display *x11_display)
   /* https://bugzilla.gnome.org/show_bug.cgi?id=710346 */
   XStoreName (x11_display->xdisplay, guard_window, "mutter guard window");
 
-  {
-    if (!meta_is_wayland_compositor ())
-      {
-        MetaBackendX11 *backend =
-          META_BACKEND_X11 (backend_from_x11_display (x11_display));
-        Display *backend_xdisplay = meta_backend_x11_get_xdisplay (backend);
-        unsigned char mask_bits[XIMaskLen (XI_LASTEVENT)] = { 0 };
-        XIEventMask mask = { XIAllMasterDevices, sizeof (mask_bits), mask_bits };
+#ifdef HAVE_X11
+  if (!meta_is_wayland_compositor ())
+    {
+      MetaBackendX11 *backend =
+        META_BACKEND_X11 (backend_from_x11_display (x11_display));
+      Display *backend_xdisplay = meta_backend_x11_get_xdisplay (backend);
+      unsigned char mask_bits[XIMaskLen (XI_LASTEVENT)] = { 0 };
+      XIEventMask mask = { XIAllMasterDevices, sizeof (mask_bits), mask_bits };
 
-        XISetMask (mask.mask, XI_ButtonPress);
-        XISetMask (mask.mask, XI_ButtonRelease);
-        XISetMask (mask.mask, XI_Motion);
+      XISetMask (mask.mask, XI_ButtonPress);
+      XISetMask (mask.mask, XI_ButtonRelease);
+      XISetMask (mask.mask, XI_Motion);
 
-        /* Sync on the connection we created the window on to
-         * make sure it's created before we select on it on the
-         * backend connection. */
-        XSync (x11_display->xdisplay, False);
+      /* Sync on the connection we created the window on to
+        * make sure it's created before we select on it on the
+        * backend connection. */
+      XSync (x11_display->xdisplay, False);
 
-        XISelectEvents (backend_xdisplay, guard_window, &mask, 1);
-      }
-  }
+      XISelectEvents (backend_xdisplay, guard_window, &mask, 1);
+    }
+#endif
 
   meta_stack_tracker_record_add (x11_display->display->stack_tracker,
                                  guard_window,
@@ -1951,6 +2182,8 @@ on_monitors_changed_internal (MetaMonitorManager *monitor_manager,
     }
 
   x11_display->has_xinerama_indices = FALSE;
+
+  update_ui_scaling_factor (x11_display);
 }
 
 static Bool
@@ -2091,6 +2324,7 @@ meta_x11_display_set_input_focus (MetaX11Display *x11_display,
 {
   Window xwindow = x11_display->no_focus_window;
   gulong serial;
+  MetaFrame *frame;
 #ifdef HAVE_X11
   MetaDisplay *display = x11_display->display;
   ClutterStage *stage = CLUTTER_STAGE (meta_get_stage_for_display (display));
@@ -2098,14 +2332,15 @@ meta_x11_display_set_input_focus (MetaX11Display *x11_display,
 
   if (window && META_IS_WINDOW_X11 (window))
     {
+      frame = meta_window_x11_get_frame (window);
       /* For output-only windows, focus the frame.
        * This seems to result in the client window getting key events
        * though, so I don't know if it's icccm-compliant.
        *
        * Still, we have to do this or keynav breaks for these windows.
        */
-      if (window->frame && !meta_window_is_focusable (window))
-        xwindow = window->frame->xwindow;
+      if (frame && !meta_window_is_focusable (window))
+        xwindow = frame->xwindow;
       else
         xwindow = meta_window_x11_get_xwindow (window);
     }
@@ -2418,10 +2653,15 @@ prefs_changed_callback (MetaPreference pref,
     }
 }
 
+/**
+ * meta_x11_display_set_stage_input_region: (skip)
+ */
 void
 meta_x11_display_set_stage_input_region (MetaX11Display *x11_display,
-                                         XserverRegion   region)
+                                         XRectangle     *rects,
+                                         int             n_rects)
 {
+#ifdef HAVE_X11
   Display *xdisplay = x11_display->xdisplay;
   MetaBackend *backend = backend_from_x11_display (x11_display);
   ClutterStage *stage = CLUTTER_STAGE (meta_backend_get_stage (backend));
@@ -2429,25 +2669,18 @@ meta_x11_display_set_stage_input_region (MetaX11Display *x11_display,
 
   g_return_if_fail (!meta_is_wayland_compositor ());
 
+  if (x11_display->stage_input_region)
+    XFixesDestroyRegion (xdisplay, x11_display->stage_input_region);
+
+  x11_display->stage_input_region = XFixesCreateRegion (xdisplay, rects, n_rects);
+
   stage_xwindow = meta_x11_get_stage_window (stage);
   XFixesSetWindowShapeRegion (xdisplay, stage_xwindow,
-                              ShapeInput, 0, 0, region);
+                              ShapeInput, 0, 0, x11_display->stage_input_region);
   XFixesSetWindowShapeRegion (xdisplay,
                               x11_display->composite_overlay_window,
-                              ShapeInput, 0, 0, region);
-}
-
-void
-meta_x11_display_clear_stage_input_region (MetaX11Display *x11_display)
-{
-  if (x11_display->empty_region == None)
-    {
-      x11_display->empty_region = XFixesCreateRegion (x11_display->xdisplay,
-                                                      NULL, 0);
-    }
-
-  meta_x11_display_set_stage_input_region (x11_display,
-                                           x11_display->empty_region);
+                              ShapeInput, 0, 0, x11_display->stage_input_region);
+#endif
 }
 
 /**
@@ -2570,3 +2803,14 @@ meta_x11_display_lookup_xwindow (MetaX11Display *x11_display,
 
   return None;
 }
+
+/**
+ * meta_display_get_x11_display: (skip)
+ * @display: a #MetaDisplay
+ *
+ */
+MetaX11Display *
+meta_display_get_x11_display (MetaDisplay *display)
+{
+  return display->x11_display;
+}
